// Copyright  2010 Henry Golding
// This file is part of the "HInput" input abstraction layer.
// For conditions of distribution and use, see copyright notice in HInput.h

#ifndef _DeviceServiceManager_h__
#define _DeviceServiceManager_h__

#include <list>
#include "InputDeviceService.h"
#include "SmartPtr.h"
#include "Misc.h"

namespace HInput
{
	/*
		A central manager for all active input device
		services
	*/
	class DeviceServiceManager: private Misc::Uncopyable
	{
		// Allow manager to create us
		friend class InputManager;

	private:
		DeviceServiceManager();
		~DeviceServiceManager();
	
	public:
		
		void		Update();
		void		Shutdown();

		void		RegisterDeviceService(const shared_ptr<InputDeviceService>& pService);
		template<typename T>
		bool		GetDeviceService(InputDeviceService*& rpService) { return GetDeviceService(typeid(T).name(), rpService); }

	private:
		bool		GetDeviceService(const char* szTypeName, InputDeviceService*& rpService);
		std::list<shared_ptr<InputDeviceService> >	m_pDeviceServices;

	};


} // end namespace HInput

#endif // _DeviceServiceManager_h__