/* 
The HInput License
Copyright  2010 Henry Golding

This software is provided 'as-is', without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.

Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.
2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.
3. This notice may not be removed or altered from any source distribution.
*/

#ifndef _HInput_h__
#define _HInput_h__

/*
	This file is provides access to the essential client elements of
	the HInput library.
*/

// Auto-add libs
#ifdef _DEBUG
	#pragma comment( lib, "HInput_Debug.lib" )
#else
	#pragma comment( lib, "HInput.lib" )	
#endif // _DEBUG


#include "InputManager.h"
#include "Enums.h"
#include "Identifier.h"
#include "InputListener.h"

namespace HInput
{
	// Fwd dec
	class TimeSource;

	namespace System
	{
		/*
			Call this to initialize the system. You may optionally 
			enable wiimote support and provide a custom time source
			and logging callback (there is a default time source
			but no log messages will be printed if you do not provide 
			a callback

			NOTE: From 27 Mar there is no longer Wii remote support
		*/
		void Initialize(	bool bSupportKeyboard = true,
							bool bSupportXInput = true,
							bool bSupportWiimote = false,
							::HInput::TimeSource* pClock = NULL,
							::HInput::InputManager::LogCallback pLogCallback = NULL );

		/*
			Call this once per frame to update the system
		*/
		void Update();

		/*
			Call this before program end to safely shutdown the system
		*/
		void Shutdown();


	} // namespace System

} // namespace HInput

#endif // _HInput_h__