// Copyright  2010 Henry Golding
// This file is part of the "HInput" input abstraction layer.
// For conditions of distribution and use, see copyright notice in HInput.h

#ifndef _Identifier_h__
#define _Identifier_h__

#include <string>

namespace HInput
{
	/*
		This is the basic identifier used by the HInput system.

		It is anticipated that some clients may wish to use their
		own form of identifier, to avoid the overhead of string
		comparisons. Therefore, identifiers are encapsulated here
		so that they can be more easily re-defined if required.
	*/

	class Identifier
	{
	public:
		Identifier();
		Identifier(const char* pOther);
		Identifier(const std::string& other);
		const Identifier& operator=(const Identifier& other);
		~Identifier();
	
		const std::string&	ToString() const { return m_String; }
		std::wstring		ToWideString() const;

		// The most important bit
		bool operator==(const Identifier& other) const;
		bool operator!=(const Identifier& other) const;

	private:
		std::string		m_String;
	};


} // end namespace HInput

#endif // _Identifier_h__