// Copyright  2010 Henry Golding
// This file is part of the "HInput" input abstraction layer.
// For conditions of distribution and use, see copyright notice in HInput.h

#ifndef _InputDeviceService_h__
#define _InputDeviceService_h__

#include "Identifier.h"

namespace HInput
{
	class TimeSource;

	/*
		This is a simple interface for input devices that
		our inputs might want to use. The interface is really
		just for the manager's benefit, it is expected that the
		users will cast the service to the appropriate type, since
		services will have different features
	*/
	class InputDeviceService
	{
	private:
		// Don't copy
		InputDeviceService(const InputDeviceService&);
		const InputDeviceService& operator=(const InputDeviceService&);

	public:
		InputDeviceService() {}
		virtual ~InputDeviceService() {}
	
		// Do any necessary initialization
		virtual void Init		(const TimeSource& timer) = 0;

		// Called by the framework automatically once per frame
		virtual void Update		(const TimeSource& timer) = 0;

		// Do any necessary shutdown
		virtual void Shutdown	() = 0;
	};

} // end namespace HInput

#endif // _InputDeviceService_h__