// Copyright  2010 Henry Golding
// This file is part of the "HInput" input abstraction layer.
// For conditions of distribution and use, see copyright notice in HInput.h

#ifndef _Plugin_HINPUT_h__
#define _Plugin_HINPUT_h__

#define WIN32_LEAN_AND_MEAN
#include "Windows.h"
#undef WIN32_LEAN_AND_MEAN

#include "Identifier.h"
#include <string>
#include "SmartPtr.h"
#include <vector>

namespace HInput
{
	// Fwd decs
	class InputDeviceService;
	class InputCreatorBase;

	/*
		Plugin encapsulates a dynamically loaded source
		of inputs and input device services. It is not intended
		to be polymorphic.
	*/
	class Plugin
	{
	private:
		Plugin(); // not implemented

		// The signature of the function in the dll that will 
		// register device(s) with our DeviceServiceManager
		//typedef bool (*RegisterDevice)(void* /*DeviceServiceManager*/);
		typedef bool (*RegisterDevice)( std::vector< shared_ptr<InputDeviceService> >& );
		
		// The signature of the function in the dll that will 
		// register input creators(s) with our InputFactory
		//typedef bool (*RegisterInputs)(void* /*InputFactory*/);
		typedef std::vector< std::pair<Identifier, shared_ptr<InputCreatorBase> > > InputPairList;
		typedef bool (*RegisterInputs)( InputPairList& );

	public:
		explicit Plugin(const std::string& dllFilename);
		~Plugin();

		bool			IsLoaded() const { return m_hinst != NULL; }
		
	private:

		bool			LoadDll();	// Called automatically from c'tor
		void			UnloadDll();// Called automatically from d'tor
		void			PrintWin32ErrorTrace();
		
		std::string		m_dllFilename;
		RegisterDevice	m_pRegisterDevice;
		RegisterInputs	m_pRegisterInputs;
		HINSTANCE		m_hinst;
	};

} // end namespace HInput

#endif // _Plugin_HINPUT_h__